@@ -12,7 +12,7 @@
 #'  For more sophisticated simulations, we strongly recommend using PedigreeSim V2.0
 #'  \url{https://www.wur.nl/en/show/Software-PedigreeSim.htm}
 #'
-#' @param m ploidy level. Must be an even number
+#' @param ploidy ploidy level. Must be an even number
 #' 
 #' @param rf.vec vector containing the recombination fractions between
 #'     adjacent markers. If a single recombination fraction is
@@ -47,9 +47,9 @@
 #'     \code{\link[mappoly]{read_geno}} for more information
 #'
 #' @examples
-#'     h.temp<-sim_homologous(m=6, n.mrk=20, max.d=3, max.ph=3, seed=123)
-#'     fake.poly.dat<-poly_cross_simulate(m=6, rf.vec=.05, n.mrk=20,
-#'                                   n.ind=200, h.temp, seed=123)
+#'     h.temp <- sim_homologous(ploidy = 6, n.mrk = 20, max.d = 3, max.ph = 3, seed = 123)
+#'     fake.poly.dat <- poly_cross_simulate(ploidy = 6, rf.vec = .05, n.mrk = 20,
+#'                                   n.ind = 200, h.temp, seed = 123)
 #'     plot(fake.poly.dat)
 #'                                    
 #'                                   
@@ -63,43 +63,43 @@
 #'     \doi{10.1534/g3.119.400378}
 #'
 #' @export
-poly_cross_simulate<-function(m, rf.vec, n.mrk,
+poly_cross_simulate <- function(ploidy, rf.vec, n.mrk,
                               n.ind, hom.allele,
-                              draw=FALSE,
-                              file="output.pdf",
-                              seed=NULL,
+                              draw = FALSE,
+                              file = "output.pdf",
+                              seed = NULL,
                               width = 12,
                               height = 6,
                               prob.P = NULL,
                               prob.Q = NULL)
 {
-  if(length(rf.vec)==1) rf.vec<-rep(rf.vec, n.mrk-1)
-  x<-sim_cross_two_informative_parents(m,
+  if(length(rf.vec) == 1) rf.vec <- rep(rf.vec, n.mrk-1)
+  x <- sim_cross_two_informative_parents(ploidy,
                                        n.mrk,
                                        rf.vec,
                                        n.ind,
                                        hom.allele$hom.allele.p,
                                        hom.allele$hom.allele.q,
-                                       seed=seed,
+                                       seed = seed,
                                        prob.P = NULL,
                                        prob.Q = NULL)
-  if(draw==TRUE)
-    draw_cross(m,round(rf.vec,4) ,hom.allele$hom.allele.p,hom.allele$hom.allele.q,
-               file=file, width = width, height = height)
-  geno<-t(x[[1]])
-  indnames<-colnames(geno)
-  mrknames<-rownames(geno)
-  structure(list(m = m,
+  if(draw == TRUE)
+    draw_cross(ploidy,round(rf.vec,4) ,hom.allele$hom.allele.p,hom.allele$hom.allele.q,
+               file = file, width = width, height = height)
+  geno <- t(x[[1]])
+  ind.names <- colnames(geno)
+  mrk.names <- rownames(geno)
+  structure(list(ploidy = ploidy,
                  n.ind = n.ind,
                  n.mrk = n.mrk,
-                 ind.names = indnames,
-                 mrk.names = mrknames,
-                 dosage.p = hom.allele$p,
-                 dosage.q = hom.allele$q,
-                 sequence = NA,
-                 sequence.pos = NA,
+                 ind.names = ind.names,
+                 mrk.names = mrk.names,
+                 dosage.p1 = hom.allele$p,
+                 dosage.p2 = hom.allele$q,
+                 chrom = NA,
+                 genome.pos = NA,
                  geno.dose = geno,
-                 nphen=0,
-                 phen=NULL),
-            class="mappoly.data")
+                 nphen = 0,
+                 phen = NULL),
+            class = "mappoly.data")
 }
