@@ -4,8 +4,8 @@
 #' @param void internal function to be documented
 #' @keywords internal
 #'
-poly_hmm_est <-
-  function(m,
+poly_hmm_est  <- 
+  function(ploidy,
            n.mrk,
            n.ind,
            p,
@@ -20,10 +20,10 @@ poly_hmm_est <-
       if (verbose && !capabilities("long.double")){
         cat("This function uses high precision calculations, but your system's architecture doesn't support long double allocation ('capabilities('long.double') = FALSE'). Running in low precision mode.\n")
       }
-    res <-
+    res  <- 
       .Call(
         "poly_hmm_est_CPP",
-        as.numeric(m),
+        as.numeric(ploidy),
         as.numeric(n.mrk),
         as.numeric(n.ind),
         as.numeric(p),
@@ -32,7 +32,7 @@ poly_hmm_est <-
         as.numeric(dq),
         as.double(g),
         as.double(rf),
-        as.numeric(rep(0, choose(m, m / 2) ^ 2)),
+        as.numeric(rep(0, choose(ploidy, ploidy / 2) ^ 2)),
         as.double(0),
         as.numeric(verbose),
         as.double(tol),
